#!/bin/ksh
#**********************************************************
#
# IBM Confidential
#
# OCO Source Materials
#
# 5724Y97
#
# (C) Copyright IBM Corp. 2011
#
# The source code for this program is not published or
# otherwise divested of its trade secrets, irrespective of
# what has been deposited with the U.S. Copyright Office.
#
#**********************************************************
TNPFAD=tnpfad
TNPFA_DIR=/opt/tnpfa
CURRENT_TNPFA_VERSION=`tnpfa status | grep Version | awk {'print $2'} | sed 's/\.//g'`

function echo_p {
    if ( test -z "${SILENT}" ) then
        echo "$1"
    fi
}

function read_p {
    if (test -z "$NOPROMPT") then
        print -n "$1"
        print -n ' '
        read $2
    fi
}

function install_log_p
{
    if (test -n "${INSTALLLOG}") then
       echo "$1" >> ${TNPFA_INSTALL_LOG}
    fi
}

function uninstallFixPack1
{
	read_p "Uninstalling TNPFA Fix Pack 2 Version 4.1.1.5, do you wish to continue? [yes]" ANSWER

	if (test "$ANSWER" != "yes" -a -n "$ANSWER") then
	    echo_p "    Exiting Installation"
	    exit 1
	fi

	read_p "Please enter home directory of TNPFA [/opt/tnpfa] " ANSWER
	
	if [ -n "$ANSWER" ]; then
	    TNPFA_DIR=$ANSWER
	fi

        if [ ! -e ${TNPFA_DIR}/bin/tnpfa ]; then
	    echo_p "Cannot find existing install in specified directory $ANSWER, exiting installation"
	    exit 1
        fi

	${TNPFA_DIR}/bin/tnpfa stop confirm

	################################# RESTORE ############################
	BACKUP_DIR=$TNPFA_DIR/_pre4115_backup

	mv ${BACKUP_DIR}/tnpfad ${TNPFA_DIR}/bin/
	if [ $? -ne 0 ] ; then
	    echo_p "Error restoring tnpfad, exiting"
	    exit 1
	fi
	mv $BACKUP_DIR/tnpfaw ${TNPFA_DIR}/bin/
	if [ $? -ne 0 ] ; then
	    echo_p "Error restoring tnpfaw, existing"
	    exit 1
	fi

	mv $BACKUP_DIR/interfaces ${TNPFA_DIR}/etc/
	if [ $? -ne 0 ] ; then
	    echo_p "Error restoring interfaces, exiting"
	    exit 1
	fi

	mv $BACKUP_DIR/ui.modules.js ${TNPFA_DIR}/www/xhtml/js/
	if [ $? -ne 0 ] ; then
	    echo_p "Error restoring ui.modules.js, exiting"
	    exit 1
	fi

	mv $BACKUP_DIR/ui.base.js $TNPFA_DIR/www/xhtml/js/
	if [ $? -ne 0 ] ; then
	    echo_p "Error restoring ui.base.js, exiting"
	    exit 1
	fi

	rmdir ${BACKUP_DIR}
	if [ $? -ne 0 ] ; then
	    echo_p "Could not remove backup directory ${BACKUP_DIR}"
	fi

	tnpfa start confirm
}

### -----------------------------------------------------------------
VERSION=`${TNPFA_DIR}/bin/tnpfad -V 2>/dev/null | grep "Version: " | sed "s/Version: //"`
RELEASE=`${TNPFA_DIR}/bin/tnpfad -V 2>/dev/null | grep "Release: " | sed "s/Release: //"`

### -----------------------------------------------------------------------

if [ "$CURRENT_TNPFA_VERSION" -ne "4115" ]; then
    echo_p "Error: Fix Pack 2 can only be uninstalled from version 4.1.1.5, current version is $VERSION"
    exit 1
else
    uninstallFixPack1
fi
