#!/bin/ksh
#**********************************************************
#
# IBM Confidential
#
# OCO Source Materials
#
# 5724Y97
#
# (C) Copyright IBM Corp. 2011
#
# The source code for this program is not published or
# otherwise divested of its trade secrets, irrespective of
# what has been deposited with the U.S. Copyright Office.
#
#**********************************************************
TNPFAD=tnpfad
TNPFA_DIR=/opt/tnpfa
CURRENT_TNPFA_VERSION=`tnpfa status | grep Version | awk {'print $2'} | sed 's/\.//g'`

function echo_p {
    if ( test -z "${SILENT}" ) then
        echo "$1"
    fi
}

function read_p {
    if (test -z "$NOPROMPT") then
        print -n "$1"
        print -n ' '
        read $2
    fi
}

function installFixPack2
{
	read_p "Installation of TNPFA Fix Pack 2 Version 4.1.1.5, do you wish to continue? [yes]" ANSWER

	if (test "$ANSWER" != "yes" -a -n "$ANSWER") then
	    echo_p "    Exiting Installation"
	    exit 1
	fi

	read_p "Please enter home directory of TNPFA [/opt/tnpfa] " ANSWER
	
	if [ -n "$ANSWER" ]; then
	    TNPFA_DIR=$ANSWER
	fi

        if [ ! -e ${TNPFA_DIR}/bin/tnpfa ]; then
	    echo_p "Cannot find existing install in specified directory $ANSWER, exiting installation"
	    exit 1
        fi

	${TNPFA_DIR}/bin/tnpfa stop confirm

	BACKUP_DIR=$TNPFA_DIR/_pre4115_backup
	echo_p "  Creating backup directory $BACKUP_DIR "
	mkdir ${BACKUP_DIR} 2> /dev/null
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred creating backup directory ${BACKUP_DIR}, exiting instllation."
	    exit 1
	fi
	echo_p "  Backing up files to $BACKUP_DIR "
	cp $TNPFA_DIR/bin/tnpfad ${BACKUP_DIR} 
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up tnpfad, exiting instllation."
	    exit 1
	fi
	cp $TNPFA_DIR/bin/tnpfaw ${BACKUP_DIR}
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up tnpfaw, exiting instllation."
	    exit 1
	fi

	cp $TNPFA_DIR/etc/interfaces ${BACKUP_DIR}
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up interfaces, exiting instllation."
	    exit 1
	fi

	cp $TNPFA_DIR/www/xhtml/js/ui.modules.js ${BACKUP_DIR}
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up ui.modules.js, exiting instllation."
	    exit 1
	fi

	cp $TNPFA_DIR/www/xhtml/js/ui.base.js ${BACKUP_DIR}
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up ui.base.js, exiting instllation."
	    exit 1
	fi

	cp ui.base.js $TNPFA_DIR/www/xhtml/js/
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up ui.base.js, exiting instllation."
	    exit 1
	fi

	cp ui.modules.js $TNPFA_DIR/www/xhtml/js/
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up ui.modules.js, exiting instllation."
	    exit 1
	fi

	cp interfaces $TNPFA_DIR/etc/
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up interfaces, exiting instllation."
	    exit 1
	fi

	cp tnpfaw $TNPFA_DIR/bin/
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up tnpfaw, exiting instllation."
	    exit 1
	fi

	cp tnpfad $TNPFA_DIR/bin/
	if [ $? -ne 0 ] ; then
	    echo_p "Error occurred backing up tnpfad, exiting instllation."
	    exit 1
	fi

	tnpfa start confirm
}

### -----------------------------------------------------------------
VERSION=`./${TNPFAD} -V 2>/dev/null | grep "Version: " | sed "s/Version: //"`
RELEASE=`./${TNPFAD} -V 2>/dev/null | grep "Release: " | sed "s/Release: //"`
### -----------------------------------------------------------------------

if [ "$CURRENT_TNPFA_VERSION" -ne "4110" ]; then
	if [ "$CURRENT_TNPFA_VERSION" -ne "4113" ]; then
		if [ "$CURRENT_TNPFA_VERSION" -ne "4114" ]; then
		    echo_p "Error: This Interim Fix can only be applied to Version 4.1.1 or 4.1.1.3 or 4.1.1.4 of TNPFA."
		    exit 1
		fi
	fi
fi
installFixPack2

